@@ -5,6 +5,7 @@ import re
 import sys
 import time
 
+import attr
 import psutil
 import pytest
 
@@ -16,8 +17,10 @@ from saltfactories.utils.processes import _get_cmdline
 
 PROCESS_START_TIMEOUT = 2
 
+log = logging.getLogger(__name__)
 
-def kill_children(procs):  # pragma: no cover
+
+def kill_children(procs):  # pragma: nocover
     _, alive = psutil.wait_procs(procs, timeout=3)
     for p in alive:
         p.kill()
@@ -112,7 +115,7 @@ def test_daemon_process_termination(request, tempfiles):
     )
     daemon.terminate()
     assert psutil.pid_exists(daemon_pid) is False
-    for child in list(children):  # pragma: no cover
+    for child in list(children):  # pragma: nocover
         if psutil.pid_exists(child.pid):
             continue
         children.remove(child)
@@ -265,7 +268,7 @@ def test_started_context_manager(request, tempfiles, start_timeout):
         started = None
         with daemon.started(start_timeout=start_timeout):
             # We should not even be able to set the following variable
-            started = False  # pragma: no cover
+            started = False  # pragma: nocover
     assert started is None
     match = re.search(r"which took (?P<seconds>.*) seconds", str(exc.value))
     assert match
@@ -348,6 +351,89 @@ def test_stopped_context_manager(request, factory_stopped_script):
         assert daemon.is_running()
 
 
+@attr.s
+class CallbackState:
+    daemon = attr.ib()
+    before_stop_callback_called = attr.ib(default=False)
+    after_stop_callback_called = attr.ib(default=False)
+    before_start_callback_called = attr.ib(default=False)
+    after_start_callback_called = attr.ib(default=False)
+
+    def before_stop_callback(self, daemon):
+        assert daemon is self.daemon
+        self.before_stop_callback_called = True
+
+    def after_stop_callback(self, daemon):
+        assert daemon is self.daemon
+        self.after_stop_callback_called = True
+
+    def before_start_callback(self, daemon):
+        assert daemon is self.daemon
+        self.before_start_callback_called = True
+
+    def after_start_callback(self, daemon):
+        assert daemon is self.daemon
+        self.after_start_callback_called = True
+
+
+def test_stopped_context_manager_callbacks(request, factory_stopped_script):
+
+    daemon = DaemonFactory(
+        cli_script_name=sys.executable,
+        base_script_args=[factory_stopped_script],
+        start_timeout=3,
+        max_start_attempts=1,
+        check_ports=[12345],
+    )
+    # Make sure the daemon is terminated no matter what
+    request.addfinalizer(daemon.terminate)
+
+    daemon_started_once = False
+    with daemon.started():
+        daemon_started_once = daemon.is_running()
+        assert daemon_started_once is True
+
+        callbacks = CallbackState(daemon)
+        assert callbacks.before_stop_callback_called is False
+        assert callbacks.after_stop_callback_called is False
+        assert callbacks.before_start_callback_called is False
+        assert callbacks.after_start_callback_called is False
+        with daemon.stopped(
+            before_stop_callback=callbacks.before_stop_callback,
+            after_stop_callback=callbacks.after_stop_callback,
+            before_start_callback=callbacks.before_start_callback,
+            after_start_callback=callbacks.after_start_callback,
+        ):
+            assert daemon.is_running() is False
+            assert callbacks.before_stop_callback_called is True
+            assert callbacks.after_stop_callback_called is True
+            assert callbacks.before_start_callback_called is False
+            assert callbacks.after_start_callback_called is False
+        assert daemon.is_running()
+        assert callbacks.before_stop_callback_called is True
+        assert callbacks.after_stop_callback_called is True
+        assert callbacks.before_start_callback_called is True
+        assert callbacks.after_start_callback_called is True
+
+        # Reset the callbacks state
+        callbacks.before_stop_callback_called = False
+        callbacks.after_stop_callback_called = False
+        callbacks.before_start_callback_called = False
+        callbacks.after_start_callback_called = False
+
+        # Let's got through stopped again, the callbacks should not be called again
+        # because they are not passed into .stopped()
+        with daemon.stopped():
+            assert daemon.is_running() is False
+        assert daemon.is_running()
+        assert callbacks.before_stop_callback_called is False
+        assert callbacks.after_stop_callback_called is False
+        assert callbacks.before_start_callback_called is False
+        assert callbacks.after_start_callback_called is False
+
+    assert daemon_started_once is True
+
+
 def test_context_manager_returns_class_instance(tempfiles):
     script = tempfiles.makepyfile(
         r"""
@@ -386,7 +472,7 @@ def test_context_manager_returns_class_instance(tempfiles):
     with pytest.raises(RuntimeError):
         with daemon as d:
             # We should not even be able to set the following variable
-            started = d.is_running()  # pragma: no cover
+            started = d.is_running()  # pragma: nocover
     assert d is None
     assert started is None
 
