@@ -1,3 +1,5 @@
+import shutil
+
 import pytest
 
 from saltfactories.exceptions import FactoryNotStarted
@@ -5,10 +7,12 @@ from saltfactories.factories.base import SaltDaemonFactory
 
 
 @pytest.fixture
-def config_dir(testdir):
-    _conf_dir = testdir.mkdir("conf")
-    yield _conf_dir
-    _conf_dir.remove(rec=1, ignore_errors=True)
+def config_dir(pytester):
+    _conf_dir = pytester.mkdir("conf")
+    try:
+        yield _conf_dir
+    finally:
+        shutil.rmtree(str(_conf_dir), ignore_errors=True)
 
 
 @pytest.fixture
@@ -18,20 +22,20 @@ def master_id():
 
 @pytest.fixture
 def config_file(config_dir, master_id):
-    config_file = config_dir.join("config").strpath
+    config_file = str(config_dir / "config")
     with open(config_file, "w") as wfh:
         wfh.write("id: {}\n".format(master_id))
     return config_file
 
 
 def test_extra_cli_arguments_after_first_failure(
-    request, config_dir, config_file, tempfiles, master_id, tmpdir
+    config_dir, config_file, tempfiles, master_id, tmp_path
 ):
     """
-    This test asserts that after the first start failure, the extra_cli_arguments_after_first_start_failure arguments
-    are added
+    This test asserts that after the first start failure, the extra_cli_arguments_after_first_start_failure
+    arguments are added
     """
-    output_file = tmpdir.join("output.txt")
+    output_file = tmp_path.joinpath("output.txt").resolve()
     config = {"conf_file": config_file, "id": master_id}
     script = tempfiles.makepyfile(
         r"""
@@ -41,7 +45,7 @@ def test_extra_cli_arguments_after_first_failure(
         import multiprocessing
 
         def main():
-            with open({!r}, "a") as wfh:
+            with open(r"{}", "a") as wfh:
                 wfh.write(" ".join(sys.argv))
                 wfh.write("\n")
             sys.exit(1)
@@ -51,9 +55,8 @@ def test_extra_cli_arguments_after_first_failure(
             multiprocessing.freeze_support()
             main()
         """.format(
-            output_file.strpath
+            output_file
         ),
-        executable=True,
     )
     daemon = SaltDaemonFactory(
         cli_script_name=script,
@@ -63,13 +66,15 @@ def test_extra_cli_arguments_after_first_failure(
         check_ports=[12345],
         extra_cli_arguments_after_first_start_failure=["--log-level=debug"],
     )
-    # Make sure the daemon is terminated no matter what
-    request.addfinalizer(daemon.terminate)
-    with pytest.raises(FactoryNotStarted):
-        daemon.start()
-    output_file_contents = output_file.read().splitlines()
+    with pytest.raises(FactoryNotStarted) as exc:
+        with daemon.started():
+            pass
+
+    str_exc = str(exc.value)
+    output_file_contents = output_file.read_text().splitlines()
     expected = [
-        "{} --config-dir={} --log-level=critical".format(script, config_dir.strpath),
-        "{} --config-dir={} --log-level=debug".format(script, config_dir.strpath),
+        "{} --config-dir={} --log-level=critical".format(script, config_dir),
+        "{} --config-dir={} --log-level=debug".format(script, config_dir),
     ]
     assert output_file_contents == expected
+    assert "Exitcode: 1" in str_exc
